# New Prod Config

## Prod_ID

20230829_src5_dec3476_v0.10_tuned

## Short description of the config

dec_3476 with NSB tuning to src5, src-dependent and lstchain v0.10 configuration.

## Why this config is needed

Reprocess the data at declination 34.76 with version of lstchain v0.10 and with tunning for src5.

## Other information


### command-line:
```
lstmcpipe_generate_config PathConfigAllSkyFull --prod_id 20230829_src5_dec3476_v0.10_tuned  --dec_list dec_3476
```
